@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.29_01';
+our $VERSION = '0.33_01';
 
 use AnyEvent::RipeRedis::Error;
 
@@ -487,11 +487,10 @@ sub _prepare {
     weaken($self);
 
     $cmd->{on_reply} = sub {
-      my $reply = shift;
-      my $err   = shift;
+      my $err = $_[1];
 
       if ( defined $err ) {
-        $self->{on_error}->( $err, $reply );
+        $self->{on_error}->($err);
         return;
       }
     };
@@ -564,6 +563,8 @@ sub _execute {
         && $self->{reconnect_interval} > 0 )
       {
         unless ( defined $self->{_reconnect_timer} ) {
+          weaken($self);
+
           $self->{_reconnect_timer} = AE::timer(
             $self->{reconnect_interval}, 0,
             sub {
@@ -1181,7 +1182,7 @@ Specifies L<AnyEvent::Handle> parameters.
     linger   => 60,
   }
 
-Enabling of the C<autocork> parameter can improve perfomance. See
+Enabling of the C<autocork> parameter can improve performance. See
 documentation on L<AnyEvent::Handle> for more information.
 
 =item on_connect => $cb->()
